/*
*            k145u.h
*       заголовочный файл
*  базового модуля имиации часов 
*   на основе К145ИК1901
*  расширенная версия на основе
*  ардуино-нано (про-мини),
*  RTC DS3231,
*  10-позиционного ЖКИ дисплея на NJU6432x
*  и минимальной клавиатуры (4-5 кнопок)
*  используюшей курсор с привязкой
*  к "пиктограммам"
*  с возможностью расширения функционала ПРВ
*  
*/
//-------------------------------------------------------
 #ifndef _k145u_H  // Блокируем повторное включение этого модуля
 #define _k145u_H

//------------------
// подключение функционала референса arduinoIDE
#if ARDUINO >= 100
 #include "Arduino.h"
#else
 #include "WProgram.h"
#endif

//------------------

//---------------------------------------------------------
// #include <avr/pgmspace.h> // подключить библиотеку работ с таблицами в ПЗУ
// #include <EEPROM.h> // "стандартная" ардуино библиотека ЕЕПРОМ

#include "sksi.h" // заголовочник сканера кноп консоли
#include "nju6432xm.h" // относится к библиотеке,
              // обслуживающей дисплей на основе nju6432m
//#include "max72m.h" // относится к библиотеке,
              // обслуживающей дисплей на основе MAX7219
#include "bdbc.h" // табличные кодер/декодеры
              // упакованного двоично-десятичного значения 00-99
              //в код двоичный и обратно
#include "mxiicr.h" // заголовочный *.h файл комплекта библиотеки mxiicm
              // (только физический протокол пересылки байта)

//         ------- devices -------

#include "mainrtc.h" // заголовочник устройства "главные часы" (RTC)
#include "secmetr.h" // заголовочник субустройства "секундомер"


//------------------------------------------------------------------------
// раскладка управляющих линий (выводов)

//------------------------------------------------------------------------
// определение/инициализация входных линий МК в соответствии
// с номерами кнопок (сенсоров),
// активный уровень на линии сенсора = 0
const byte PinToV =18; // D18 линия кнопки S4(Vkey)
const byte PinToM =17; // D17 линия кнопки S3(Down)
const byte PinToP =16; // D16 линия кнопки S2(Up)
const byte PinToR =15; // D15 линия кнопки S1(Right)
const byte PinToL =14; // D14 линия кнопки S0(Left)

// обьявление и инициализация управляющих выводов NJU6432
const byte PinNoInh =9; // линия управления дисплея (бланкирование)
const byte PinDn =10; // линия данных дисплея
const byte PinScl =11; // тактовый строб сопровождения данных дисплея
const byte PinCe =12; // линия разрешения обмена дисплея

// константа интервала опросов клавиатуры (сенсоров) в милисекундах
const byte skstm = 35;

//------------------------------------------------------------------------
// инициализация управляющих выводов RTC
const byte L_OS = 3; // вывод строба/прерываний RTC
const byte L_SDA = 4; // вывод данных I2C
const byte L_SCL = 5; // вывод строба I2C

//------------------------------------------------------------------------
// инициализация управляющих выводов аппаратной обвязки 
const byte HLtmr = 8; // сигнального выхода таймера
const byte HLbud = 6; // сигнальный вывод комплекта бодунов *!!
const byte DTM = 7; // сигнальный вывод звуковой головки

//------------------------------------------------------------------------
// инициализация дополнительных выводов управления
// разрешение запросов исполнения селектора клавиатуры
const byte EnSn = 13; // D.. линия внешнего выключателя

// управляющий вывод исполнения начальной активации RTC
const byte magikKey = 1; // D..


//------------------------------------------------------------------------
// система контроля питающего напряжения
/*
const byte Apwr=7; // вход АЦП
const int Up5=460;
const int Up4_5=414;
const int Up4_2=387;
const int Up4=368;
const int Up3_8=350;
const int Up3_5=322;
const int Up3_4=313;
const int Upares=300;
const int Up2_8=258;
*/

// индикация необходимости включить зарядку
//void lowBat();

//------------------------------------------------------------------------
// указатели на функции возврата в предыдущий модуль устройства
// (стек возврата из субменю) 3 уровня
// "растет вверх"
// заполняется при вызове субменю,
// опустошается по завершении выполнения
// функции возврата из субменю
volatile KeyPtr RetSteckL = stub; // уровень 0
volatile KeyPtr RetSteckH = stub; // уровень 1
volatile KeyPtr RetSteckU = stub; // уровень 2
// указатели на функции инициализации
// имеющихся в системе "устройств"
volatile KeyPtr dev0_init = DevClockInit; // основная панель главных часов
volatile KeyPtr dev1_init = secmetrInit; // секундомер
volatile KeyPtr dev2_init = stub; // таймер обратного отсчета
volatile KeyPtr dev3_init = stub; // настройка параметров будильников
/*
volatile KeyPtr dev4_init = stub; // 
volatile KeyPtr dev5_init = stub; //
volatile KeyPtr dev6_init = stub; //
volatile KeyPtr dev7_init = stub; //
*/

// временная заглушка тест-сборки
// закомментировать(удалить)при наличии хотя бы одного файла
// "устройства"(Device) в проекте
//(stub заменяется на целевые функции в модуле устройства)
volatile KeyPtr KeyPtrZ = stub; // указатель на функцию "все отпущены"
volatile KeyPtr KeyPtrL = stub; // указатель на функцию "сдвиг курсора влево"
volatile KeyPtr KeyPtrR = stub; // указатель на функцию "сдвиг курсора вправо"
volatile KeyPtr KeyPtrP = stub; // указатель на функцию "+"
volatile KeyPtr KeyPtrM = stub; // указатель на функцию "-"
volatile KeyPtr KeyPtrRK = stub; // указатель на функцию "RK"
/*
volatile KeyPtr KeyPtr_LR = stub; // указатель на функцию "<<" & ">>"
volatile KeyPtr KeyPtr_PM = stub; // указатель на функцию "+" & "-"
volatile KeyPtr KeyPtr_LP = stub; // указатель на функцию "<<" & "+"
volatile KeyPtr KeyPtr_RP = stub; // указатель на функцию ">>" & "+"
volatile KeyPtr KeyPtr_LM = stub; // указатель на функцию "<<" & "-"
volatile KeyPtr KeyPtr_RM = stub; // указатель на функцию ">>" & "-"
*/

//------------------------------------------------------------------------
// селектор задач для активных кноп/комбинаций кноп
// текущего устройства
extern void KeyDevFnSel();

//-------------------------------------------------------


//-------------------------------------------------------






//-------------------------------------------------------

#endif

//-------------конец файла/end of file---------------------
