/* ------------------------------------------------------- */
/* основной файл устройства главные часы (RTC) mainrtc.cpp */
//******************************************************************************
//  Секция include: здесь подключается заголовочный файл к модулю
//******************************************************************************

#include "mainrtc.h" // заголовочный *.h файл текущего проекта

//------------------------------------------------------------------------

// транзитный счетчик контроля отказа линии внешнего
// секунд-генератора
volatile byte ErIrqRTC =0;
// передаточный флаг запроса обработчика очередной секунды
volatile byte SecF = 0;

// байт секунд внутреннего счета
volatile byte S_int = 0;
// байт минут внутреннего счета
volatile byte M_int = 0;
// байт часов внутреннего счета
volatile byte H_int = 0;
// временные байты обработки календаря
volatile byte tmp_rtc_sec = 0; // данные из адрес регистра секунд
volatile byte tmp_rtc_min = 0; // данные из адрес регистра минут
volatile byte tmp_rtc_hours = 0; // данные из адрес регистра часов
volatile byte tmp_rtc_day = 0; // данные из регистра дня недели
volatile byte tmp_rtc_date = 0; // данные из регистра даты (число)
volatile byte tmp_rtc_mons = 0; // данные из регистра месяца
volatile byte tmp_rtc_year = 0; // данные из регистра года


//------------------------------------------------------------------------


//------------------------------------------------------------------------



//------------------------------------------------------------------------

// запуск секунд-генератора от RTC
void genSecInit()
{
 cli();
 attachInterrupt(digitalPinToInterrupt(L_OS), RtcSec, FALLING);
 sei();
}
// ежескундное прерывание от RTC
void RtcSec(){ SecF = 1; }

// функция счета времени
void clock()
{
 S_int++;
 if(S_int == 60)
  {
   S_int = 0; M_int++;
   if(M_int == 60)
    {
     M_int = 0; H_int++;
     if(H_int == 24){H_int = 0;}
    }
  }
}

// функция преобразования и вывода на индикатор
// данных главных часов
void vrClcDisp()
{ byte tmp;
 njx.v_ram[9] = fnt_bl;
 tmp = pgm_read_byte_near( BinDec + S_int );
 njx.v_ram[8] = njx.znak((tmp & B00001111));
 njx.v_ram[7] = njx.znak(((tmp>>4) & B00001111));
 njx.v_ram[6] = fnt_minus;
 tmp = pgm_read_byte_near( BinDec + M_int );
 njx.v_ram[5] = njx.znak((tmp & B00001111));
 njx.v_ram[4] = njx.znak(((tmp>>4) & B00001111));
 njx.v_ram[3] = fnt_minus;
 tmp = pgm_read_byte_near( BinDec + H_int );
 njx.v_ram[2] = njx.znak((tmp & B00001111));
 njx.v_ram[1] = njx.znak(((tmp>>4) & B00001111));
 njx.v_ram[0] = fnt_bl;
 njx.WRglass();
}

// функция блокировки по отсутствию тактовых
// секунд-импульсов от RTC
void ERROR_RTC()
{
 labelEror();
 // блокировка используемой силовой периферии
 // и источников команд(данных) ее управления

 njx.v_ram[5] = fnt_r; // загрузка прикладного фрагмента
 njx.v_ram[6] = fnt_c; // "rcLc"
 njx.v_ram[7] = fnt_L;
 njx.v_ram[8] = fnt_c;
 njx.WRglass();
 while (1)
 {
  // звуковой сигнал по желанию
 }
}

// функция ошибки обмена по I2C
void erlinIIC()
{
 labelEror();
 // блокировка используемой силовой периферии
 // и источников команд(данных) ее управления

 njx.v_ram[5] = fnt_r; // загрузка прикладного фрагмента
 njx.v_ram[6] = fnt_I; // "rI2C"
 njx.v_ram[7] = fnt_2;
 njx.v_ram[8] = fnt_C;
 njx.WRglass();
 while (1)
 {
  // звуковой сигнал по желанию
 }
}


// функция "холодного старта"
//(начальной инициализации параметров)
// для DS3231, запускающая секунд-генератор
// при подключении нового RTC (по "волшебной кнопе")
extern void ColdStartRTC()
{
 
}

// инициализация устройства "главные часы"

extern void DevClockInit()
{ static byte PGset = 0;
 // очистка дисплея
 njx.BlankVram(fnt_bl);
 // разрешить вывод на индикацию главных часов
 DisClcInd = 0;
 // считать часы и календарь из RTC в блок копии хранения
 // только при первичной подаче питания
 // при переключении меджу "устройствами" не требуется
 if(!PGset)
 { 
  ReadClokBooc(); PGset = 1;
  // преобразовать секунды, минуты и часы в двоичный формат
  S_int = pgm_read_byte_near( DecBin + tmp_rtc_sec );
  M_int = pgm_read_byte_near( DecBin + tmp_rtc_min );
  H_int = pgm_read_byte_near( DecBin + tmp_rtc_hours );
  // и записать результат в соответствующий регистры главных часов
 }
 // провести вывод данных на индикацию
 vrClcDisp();
 // выполнить переприсвоение указателей комбинаций
 // к требуемому для основного статуса "устройства"
 // (индикация часов в ожидании команд клавиатуры)
 KeyPtrL = dev1_init; // указатель на функцию "<<"
 KeyPtrR = stub; // указатель на функцию ">>"
 KeyPtrP = stub; // указатель на функцию "+"
 KeyPtrM = stub; // указатель на функцию "-"
 KeyPtrRK = stub; // указатель на функцию "RK"
 // загрузить указатель стека возврата
 RetSteckU = RetSteckH;
 RetSteckH = RetSteckL;
 RetSteckL = DevClockInit;
}

// функция "чтение часов и календаря"
void ReadClokBooc()
{
 byte error = 0;
 my_iic.mx_Start(); error = my_iic.mx_Txd(ds3231_W);
 if (error){ erlinIIC();}
 error = my_iic.mx_Txd(adr_rtc_sec);
 if (error){ erlinIIC();}
 my_iic.mx_reStart();
 error = my_iic.mx_Txda(ds3231_R);
 if (error){ erlinIIC();}
 tmp_rtc_sec = my_iic.mx_Rxd(mx_Ack); // данные из адрес регистра секунд
 tmp_rtc_min = my_iic.mx_Rxd(mx_Ack); // данные из адрес регистра минут
 tmp_rtc_hours = my_iic.mx_Rxd(mx_Ack); // данные из адрес регистра часов
 tmp_rtc_day = my_iic.mx_Rxd(mx_Ack); // данные из регистра дня недели
 tmp_rtc_date = my_iic.mx_Rxd(mx_Ack); // данные из регистра даты (число)
 tmp_rtc_mons = my_iic.mx_Rxd(mx_Ack); // данные из регистра месяца
 tmp_rtc_year = my_iic.mx_Rxd(mx_noAck); // данные из регистра года
 my_iic.mx_Stop();
}



//------------------------------------------------------------------------
//-------------конец файла/end of file---------------------
