/* --------------------------------------------------------- */
/* заголовочный файл устройства главные часы (RTC) mainrtc.h */
/*---------------------------------------------------------- */
#ifndef _mainrtc_H   // Блокируем повторное включение этого модуля
#define _mainrtc_H
//------------------------------------------------------------------------
// обязательная "магическая добавка" (начало)
#if ARDUINO >= 100
 #include "Arduino.h"
#else
 #include "WProgram.h"
#endif
// обязательная "магическая добавка" (конец)
//------------------------------------------------------------------------
// #include <avr/interrupt.h> // обслуживание прерываний
// #include <avr/pgmspace.h> // подключить библиотеку работ с таблицами в ПЗУ
#include "sksi.h" // библиотека sksi
#include "nju6432xm.h" // относится к библиотеке,
               // обслуживающей дисплей на основе nju6432m
//#include "max72m.h" // относится к библиотеке,
               // обслуживающей дисплей на основе MAX7219
#include "bdbc.h" // табличные кодер/декодеры
              // упакованного двоично-десятичного значения 00-99
              //в код двоичный и обратно
#include "mxiicr.h" // заголовочный *.h файл комплекта библиотеки mxiicm
                   // (только физический протокол пересылки байта)
#include "ds3231_map.h" // файл карты ресурсов RTC DS3231

//------------------------------------------------------------------------
// обьявление управляющих выводов RTC
extern const byte L_OS; // вывод строба/прерываний RTC
extern const byte L_SDA; // вывод данных I2C
extern const byte L_SCL; // вывод строба I2C

// обьявление управляющего вывода
// исполнения начальной активации RTC
extern const byte magikKey;

// транзитный счетчик контроля отказа линии внешнего
// секунд-генератора
extern volatile byte ErIrqRTC;
// передаточный флаг запроса обработчика очередной секунды
extern volatile byte SecF;

// байт секунд внутреннего счета
extern volatile byte S_int;
// байт минут внутреннего счета
extern volatile byte M_int;
// байт часов внутреннего счета
extern volatile byte H_int;
// временные байты обработки календаря
extern volatile byte tmp_rtc_sec; // данные из адрес регистра секунд
extern volatile byte tmp_rtc_min; // данные из адрес регистра минут
extern volatile byte tmp_rtc_hours; // данные из адрес регистра часов
extern volatile byte tmp_rtc_day; // данные из регистра дня недели
extern volatile byte tmp_rtc_date; // данные из регистра даты (число)
extern volatile byte tmp_rtc_mons; // данные из регистра месяца
extern volatile byte tmp_rtc_year; // данные из регистра года



//------------------------------------------------------------------------

// запуск секунд-генератора от RTC
extern void genSecInit();

// ежескундное прерывание от RTC
extern void RtcSec();

// функция счета времени
extern void clock();

// функция преобразования и вывода на индикатор
// данных главных часов
extern void vrClcDisp();

// функция блокировки по отсутствию тактовых
// секунд-импульсов от RTC
extern void ERROR_RTC();
// функция ошибки обмена по I2C
extern void erlinIIC();

// функция "холодного старта"
//(начальной инициализации параметров)
// для DS3231, запускающая секунд-генератор
// при подключении нового RTC (по "волшебной кнопе")
extern void ColdStartRTC();

// инициализация устройства "главные часы"
/*
 * очистка дисплея
 * разрешить вывод на индикацию главных часов
 * считать часы и календарь из RTC в блок копии хранения
 * преобразовать секунды, минуты и часы в двоичный формат
 * и записать результат в соответствующий регистры главных часов
 * провести вывод данных на индикацию
 * выполнить переприсвоение указателей комбинаций
 * к требуемому для основного статуса "устройства"
 * (индикация часов в ожидании команд клавиатуры)
 * загрузить указатель стека возврата
 * 
 */
extern void DevClockInit();

// функция "чтение часов и календаря"
void ReadClokBooc();


//------------------------------------------------------------------------

#endif      // Закрывающий #endif к блокировке повторного включения

//-------------конец файла/end of file---------------------
