/* ---------------------------------------------------- */
/*        основной файл сканера кнопок sksi.cpp         */
//******************************************************************************
//  Секция include: здесь подключается заголовочный файл к модулю
//******************************************************************************

#include "sksi.h" // заголовочный *.h файл текущего проекта

//------------------------------------------------------------------------

// флаг временного запрета обработки сканера клавиатуры
volatile byte DisSkan =0;
// флаг запроса обработчика нажатй комбинации
volatile byte QtTm =0;
// флаг - защелка "однократное действие выполнено"
volatile byte WS_Lock =0;
// транзитный временный буфер обработчика клавиатуры
volatile byte SnDat =0;
// транзитный счетчик таймера "склерозника"
volatile unsigned int SnWDT =0;


// флаг запрета вывода текущего времени главых
// часов на индикацию (ход часов не останавливается)
volatile byte DisClcInd = 0;


// номер текущей позиции курсора на дисплее
// 0-1-2-3-4-5-6-7-8-9
volatile byte NumPozKur =0;
// массив флагов разрешенных позиций курсора дисплея
byte EnKurF[LenPozDisp];


//******************************************************************************
//  Секция описания функций сканера кнопок
//******************************************************************************
// инициалзация выводов МК и генератора сетки опроса сенсоров/кнопок
void skan_init()
{
 pinMode(PinToV, INPUT_PULLUP); pinMode(PinToM, INPUT_PULLUP);
 pinMode(PinToP, INPUT_PULLUP); pinMode(PinToR, INPUT_PULLUP);
 pinMode(PinToL, INPUT_PULLUP);
 digitalWrite(PinToV, HIGH); digitalWrite(PinToM, HIGH);
 digitalWrite(PinToP, HIGH); digitalWrite(PinToR, HIGH);
 digitalWrite(PinToL, HIGH);
 cli(); //noInterrupts();
 OCR0A = 127; TIMSK0 |= (1<<OCIE0A); QtTm = 0; DisSkan = 0;
 sei(); //interrupts();
}

/* генератор сетки опроса сенсоров/кнопок (1mS)
 * и самого опроса ЛВК
 * по выходу при подтвержденной комбинации
 * QtTm=1, SnDat = коду комбинации,
 * SnWDT = время удержания комбинации в mS*skstm (35mS)
 */
ISR(TIMER0_COMPA_vect)
{
 static byte Cnt_A=0; static byte sn_tmp0;
 if (!DisSkan)
  {
   Cnt_A++; SnWDT++;
   if (Cnt_A == skstm)
    {
     Cnt_A=0;
     sn_tmp0 = ~((digitalRead(PinToL)<<PozToL) | \
     (digitalRead(PinToR)<<PozToR) | \
     (digitalRead(PinToP)<<PozToP) | \
     (digitalRead(PinToM)<<PozToM) | \
     (digitalRead(PinToV)<<PozToV));
     sn_tmp0 &= B00011111;
     if (SnDat == sn_tmp0){QtTm=1;}
     else {QtTm=0; SnWDT=0; SnDat = sn_tmp0;}
    }
  }
}

// функция продвижки курсора влево
void kurL()
{
  // первичное исполнение (одиночное)
 if (!WS_Lock)
  {
   WS_Lock=1;
   njx.v_ram[NumPozKur]= njx.v_ram[NumPozKur] & (~fnt_coma);
  do{
    if (NumPozKur == 0){NumPozKur = 9;}
    else {NumPozKur--;}
  } while (!EnKurF[NumPozKur]);
  njx.v_ram[NumPozKur]= njx.v_ram[NumPozKur] | fnt_coma;
  }
  // длительное удержание
 else
  {
    
  }
 njx.WRglass();
}

// функция продвижки курсора вправо
void kurR()
{
  // первичное исполнение (одиночное)
 if (!WS_Lock)
  {
   WS_Lock=1;
   njx.v_ram[NumPozKur] = njx.v_ram[NumPozKur] & (~fnt_coma);
  do{
    if (NumPozKur == 9){NumPozKur = 0;}
    else {NumPozKur++;}
  } while (!EnKurF[NumPozKur]);
  njx.v_ram[NumPozKur] = njx.v_ram[NumPozKur] | fnt_coma;
  }
  // длительное удержание
 else
  {
    
  }
 njx.WRglass();
}

// функция "плюс" счет в позиции от 0 до F
void IncPoz()
{
 // первичное исполнение (одиночное)
 if (!WS_Lock)
  {
   WS_Lock=1;
   njx.v_ram[NumPozKur] = njx.v_ram[NumPozKur] & (~fnt_coma);
   njx.v_ram[NumPozKur] = njx.overZnak(njx.v_ram[NumPozKur]);
   if (njx.v_ram[NumPozKur] == 15){njx.v_ram[NumPozKur] = 0;}
    else {njx.v_ram[NumPozKur]++;}
   njx.v_ram[NumPozKur] = njx.znak(njx.v_ram[NumPozKur]);
   njx.v_ram[NumPozKur] = njx.v_ram[NumPozKur] | fnt_coma;
  }
  // длительное удержание
 else
  {
    
  }
 njx.WRglass();
}

// функция "минус" счет в позиции от F до 0
void DecPoz()
{
 // первичное исполнение (одиночное)
 if (!WS_Lock)
  {
   WS_Lock=1;
   njx.v_ram[NumPozKur] = njx.v_ram[NumPozKur] & (~fnt_coma);
   njx.v_ram[NumPozKur] = njx.overZnak(njx.v_ram[NumPozKur]);
   if (njx.v_ram[NumPozKur] == 0){njx.v_ram[NumPozKur] = 15;}
    else {njx.v_ram[NumPozKur]--;}
   njx.v_ram[NumPozKur] = njx.znak(njx.v_ram[NumPozKur]);
   njx.v_ram[NumPozKur] = njx.v_ram[NumPozKur] | fnt_coma;
  }
  // длительное удержание
 else
  {
    
  }
 njx.WRglass();
}

// функция статуса "все отпущены/не активны"
// (возможно дополнение "контроля склерозника")
void SnZero(){ WS_Lock =0; }

// функция - заглушка (пустышка)
void stub() { }

// функция загрузки массива байт mas
// длиной в len содержимым перменной dat
extern void LdMas(byte *mas, byte len, byte dat)
{
 for (byte cnt=0; cnt<=(len-1); cnt++)
   { mas[cnt] = dat; }
}

// заставка "Егог" для вывода сообщения об ошибке
// общая для всех случаев ошибок
extern void labelEror()
{
 DisClcInd = 1; // запрет вывода главных часов на индикацию
 njx.BlankVram(fnt_bl); // очистка дисплея
 njx.v_ram[0] = fnt_E; // загрузка общего фрагмента
 njx.v_ram[1] = fnt_r; // "Eror"
 njx.v_ram[2] = fnt_o;
 njx.v_ram[3] = fnt_r;
}



//------------------------------------------------------------------------
//-------------конец файла/end of file---------------------
